==> jc-1.4.0.tar.gz: java/net/SocketTimeoutException.h <==
// public class java.net.SocketTimeoutException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class d6af3ef15ebd119c java_io_InterruptedIOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3464df93420eee96 java_net_SocketTimeoutException

// header file dependencies
// @dep_header java_io_InterruptedIOException

#include "java/io/InterruptedIOException.h"

#ifndef _JC_java_net_SocketTimeoutException_H_
#define _JC_java_net_SocketTimeoutException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_SocketTimeoutException$sub_refs	_jc_java_net_SocketTimeoutException$sub_refs;
typedef struct _jc_java_net_SocketTimeoutException$sub_nonrefs	_jc_java_net_SocketTimeoutException$sub_nonrefs;
typedef struct _jc_java_net_SocketTimeoutException$refs	_jc_java_net_SocketTimeoutException$refs;
typedef struct _jc_java_net_SocketTimeoutException$nonrefs	_jc_java_net_SocketTimeoutException$nonrefs;
typedef struct _jc_java_net_SocketTimeoutException$object	_jc_java_net_SocketTimeoutException$object;

typedef struct _jc_java_net_SocketTimeoutException$fields_struct	_jc_java_net_SocketTimeoutException$fields_struct;
typedef const struct _jc_java_net_SocketTimeoutException$vmethods	_jc_java_net_SocketTimeoutException$vmethods;
typedef const struct _jc_java_net_SocketTimeoutException$vtable	_jc_java_net_SocketTimeoutException$vtable;
typedef const struct _jc_java_net_SocketTimeoutException$vtype	_jc_java_net_SocketTimeoutException$vtype;

// Class fields structure
struct _jc_java_net_SocketTimeoutException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_SocketTimeoutException$fields_struct _jc_java_net_SocketTimeoutException$class_fields;

// Constructors
extern void _jc_java_net_SocketTimeoutException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_SocketTimeoutException$object *);
extern void _jc_java_net_SocketTimeoutException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_SocketTimeoutException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_net_SocketTimeoutException$vmethods {
};

// Vtable
struct _jc_java_net_SocketTimeoutException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_InterruptedIOException$vmethods	java_io_InterruptedIOException;
	_jc_java_net_SocketTimeoutException$vmethods	java_net_SocketTimeoutException;
};

// Vtype
struct _jc_java_net_SocketTimeoutException$vtype {
	_jc_type			type;
	_jc_java_net_SocketTimeoutException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_SocketTimeoutException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_SocketTimeoutException$refs {
    _jc_java_net_SocketTimeoutException$sub_refs	java_net_SocketTimeoutException;
    _jc_java_io_InterruptedIOException$sub_refs	java_io_InterruptedIOException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_SocketTimeoutException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_SocketTimeoutException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_InterruptedIOException$sub_nonrefs	java_io_InterruptedIOException;
    _jc_java_net_SocketTimeoutException$sub_nonrefs	java_net_SocketTimeoutException;
};

// Object instance structure
struct _jc_java_net_SocketTimeoutException$object {
	_jc_java_net_SocketTimeoutException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_SocketTimeoutException$vtype	*vtype;
	_jc_java_net_SocketTimeoutException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_SocketTimeoutException$vtype _jc_java_net_SocketTimeoutException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_SocketTimeoutException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_SocketTimeoutException$class_object;

#endif	/* _JC_java_net_SocketTimeoutException_H_ */

==> jc-1.4.6.tar.gz: java/net/SocketTimeoutException.h <==
// public class java.net.SocketTimeoutException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class d6af3ef15ebd119c java_io_InterruptedIOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3464df93420eee96 java_net_SocketTimeoutException

// header file dependencies
// @dep_header java_io_InterruptedIOException

#include "java/io/InterruptedIOException.h"

#ifndef _JC_java_net_SocketTimeoutException_H_
#define _JC_java_net_SocketTimeoutException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_SocketTimeoutException$sub_refs	_jc_java_net_SocketTimeoutException$sub_refs;
typedef struct _jc_java_net_SocketTimeoutException$sub_nonrefs	_jc_java_net_SocketTimeoutException$sub_nonrefs;
typedef struct _jc_java_net_SocketTimeoutException$refs	_jc_java_net_SocketTimeoutException$refs;
typedef struct _jc_java_net_SocketTimeoutException$nonrefs	_jc_java_net_SocketTimeoutException$nonrefs;
typedef struct _jc_java_net_SocketTimeoutException$object	_jc_java_net_SocketTimeoutException$object;

typedef struct _jc_java_net_SocketTimeoutException$fields_struct	_jc_java_net_SocketTimeoutException$fields_struct;
typedef const struct _jc_java_net_SocketTimeoutException$vmethods	_jc_java_net_SocketTimeoutException$vmethods;
typedef const struct _jc_java_net_SocketTimeoutException$vtable	_jc_java_net_SocketTimeoutException$vtable;
typedef const struct _jc_java_net_SocketTimeoutException$vtype	_jc_java_net_SocketTimeoutException$vtype;

// Class fields structure
struct _jc_java_net_SocketTimeoutException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_SocketTimeoutException$fields_struct _jc_java_net_SocketTimeoutException$class_fields;

// Constructors
extern void _jc_java_net_SocketTimeoutException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_SocketTimeoutException$object *) _JC_JCNI_ATTR;
extern void _jc_java_net_SocketTimeoutException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_SocketTimeoutException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_SocketTimeoutException$vmethods {
};

// Vtable
struct _jc_java_net_SocketTimeoutException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_InterruptedIOException$vmethods	java_io_InterruptedIOException;
	_jc_java_net_SocketTimeoutException$vmethods	java_net_SocketTimeoutException;
};

// Vtype
struct _jc_java_net_SocketTimeoutException$vtype {
	_jc_type			type;
	_jc_java_net_SocketTimeoutException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_SocketTimeoutException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_SocketTimeoutException$refs {
    _jc_java_net_SocketTimeoutException$sub_refs	java_net_SocketTimeoutException;
    _jc_java_io_InterruptedIOException$sub_refs	java_io_InterruptedIOException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_SocketTimeoutException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_SocketTimeoutException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_InterruptedIOException$sub_nonrefs	java_io_InterruptedIOException;
    _jc_java_net_SocketTimeoutException$sub_nonrefs	java_net_SocketTimeoutException;
};

// Object instance structure
struct _jc_java_net_SocketTimeoutException$object {
	_jc_java_net_SocketTimeoutException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_SocketTimeoutException$vtype	*vtype;
	_jc_java_net_SocketTimeoutException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_SocketTimeoutException$vtype _jc_java_net_SocketTimeoutException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_SocketTimeoutException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_SocketTimeoutException$class_object;

#endif	/* _JC_java_net_SocketTimeoutException_H_ */
